package
Version:
v0.0.3
Opens a new window with list of versions in this module.
Published: Jul 4, 2021
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GetMailTypes 获取邮件类型
@Title 获取邮件类型
@Author l.jiang.1024@gmail.com
@Description 获取邮件类型
@Tags mail
@Param Authorization header string true "Bearer 31a165baebe6dec616b1f8f3207b4273"
@Router /api/v1/mail-types [get]
PushMail 发送邮件
@Title 发送邮件
@Author l.jiang.1024@gmail.com
@Description 发送邮件
@Tags mail
@Param Authorization header string true "Bearer 31a165baebe6dec616b1f8f3207b4273"
@Param body body request.PushMailRequest true "JSON数据"
@Router /api/v1/mails [post]
type Option struct {
Code *int
Msg *string
Data *interface{}
}
Option option
func WithData(data interface{}) *Option
WithData With Data
Source Files
¶
Click to show internal directories.
Click to hide internal directories.